#
# spec file for package mayavi
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         X_display  ":98"
# vtk only for python3 flavor
%define         pythons python3
Name:           mayavi
Version:        4.7.4
Release:        1.5
Summary:        3D visualization of scientific data in Python
License:        BSD-3-Clause AND EPL-1.0 AND LGPL-2.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/Scientific/Other
URL:            https://github.com/enthought/mayavi
Source0:        https://files.pythonhosted.org/packages/source/m/mayavi/mayavi-%{version}.tar.gz
Source1:        mayavi.desktop
Source2:        tvtk_doc.desktop
BuildRequires:  R-base-devel
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Cython
BuildRequires:  python3-Pygments
BuildRequires:  python3-Sphinx
BuildRequires:  python3-apptools
BuildRequires:  python3-configobj
BuildRequires:  python3-devel
BuildRequires:  python3-envisage >= 3.0
BuildRequires:  python3-numpy-devel >= 1.0.1
BuildRequires:  python3-pyface >= 6.1.1
BuildRequires:  python3-qt5
BuildRequires:  python3-setuptools
BuildRequires:  python3-traits >= 6.0.0
BuildRequires:  python3-traitsui >= 7.0.0
BuildRequires:  python3-vtk >= 5.0
BuildRequires:  update-desktop-files
BuildRequires:  vtk-devel
Requires:       python3-Pygments
Requires:       python3-apptools
Requires:       python3-envisage
Requires:       python3-qt5
Requires:       python3-tvtk = %{version}
Provides:       python3-mayavi = %{version}
Recommends:     %{name}-jupyter
# SECTION test requirements
BuildRequires:  xorg-x11-server
# /SECTION

%description
Mayavi provides interactive visualization of 3-D data. It offers:

 * An (optional) user interface with dialogs to interact with
   all data and objects in the visualization.
 * A scripting interface in Python, including
   one-liners, or an object-oriented programming interface. Mayavi
   integrates with numpy and scipy for 3D plotting and can
   be used in IPython interactively, similarly to Matplotlib.
 * Use of the the VTK toolkit.

Additionally, Mayavi is a reusable tool that can be embedded in
applications in different ways or be combined with the Envisage
application-building framework to assemble domain-specific tools.

It is part of the Enthought Tool Suite (ETS).

%package     -n python3-tvtk
Summary:        A python3-traits enabled version of python3-vtk
Group:          Productivity/Scientific/Other
Requires:       python3-numpy
Requires:       python3-pyface >= 6.1.1
Requires:       python3-traits >= 6.0.0
Requires:       python3-traitsui >= 7.0.0
Requires:       python3-vtk
Recommends:     python3-configobj
Recommends:     python3-envisage >= 3.0
Recommends:     python3-wxWidgets >= 2.8

%description -n python3-tvtk
TVTK wraps VTK objects to provide a convenient, Pythonic API, while
supporting Traits attributes and NumPy/SciPy arrays. TVTK is
implemented mostly in pure Python, except for a small extension module.

Developers typically use TVTK to write Mayavi modules, and then use
Mayavi to interact with visualizations or create applications.

It is part of the Enthought Tool Suite (ETS).

%package        doc
Summary:        Documentation for mayavi
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description    doc
Documentation files for the %{name} package.

%package     -n python3-tvtk-doc
Summary:        Documentation for python3-tvtk
Group:          Documentation/HTML
Requires:       python3-tvtk = %{version}

%description -n python3-tvtk-doc
Documentation files for the python3-tvtk package.

%package        jupyter
Summary:        Jupyter notebook backend for mayavi
Group:          Productivity/Scientific/Other
Requires:       %{name} = %{version}
Requires:       jupyter-ipyevents
Requires:       jupyter-ipywidgets
Requires:       jupyter-notebook

%description    jupyter
Interface to allow plotting with mayavi in Jupyter
notebooks.

This package pulls in the dependencies needed to
run mayavi in a Jupyter notebook.

%prep
%setup -q -n mayavi-%{version}
rm -r mayavi.egg-info

# wrong-file-end-of-line-encoding
sed -i 's|\r||' examples/mayavi/data/room_vis.wrl

# spurious-executable-perm
chmod -x mayavi/tests/data/cellsnd.ascii.inp

# non-executable-script
sed -i -e '/^#!\//, 1d' integrationtests/mayavi/*.py
sed -i -e '/^#!\//, 1d' mayavi/tests/*.py
sed -i -e '/^#!\//, 1d' mayavi/tests/csv_files/csv_2_py
sed -i -e '/^#!\//, 1d' mayavi/scripts/*.py
sed -i -e '/^#!\//, 1d' tvtk/setup.py

# env-script-interpreter
find . -name \*.py -exec \
    sed -i -e '1s@#!\s*%{_bindir}/env\s*python@#!%{_bindir}/python@' '{}' \;

%build
export LANG=en_US.UTF-8
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10

export CFLAGS="%{optflags}"
%python3_build

%install
export LANG=en_US.UTF-8
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10

%python3_install

# examples and integrationtests are not installed by the build system
# Manually install examples and integrationtests in python3_sitearch
mkdir -p %{buildroot}%{python3_sitearch}/mayavi/examples
cp -R examples/mayavi/* %{buildroot}%{python3_sitearch}/mayavi/examples/
mkdir -p %{buildroot}%{python3_sitearch}/mayavi/integrationtests
cp -R integrationtests/mayavi/* %{buildroot}%{python3_sitearch}/mayavi/integrationtests/
mkdir -p %{buildroot}%{python3_sitearch}/tvtk/examples
cp -R examples/tvtk/* %{buildroot}%{python3_sitearch}/tvtk/examples/

# Remove shebang from .py files in examples and integrationtests
# as they are not supposed to be executed
find %{buildroot}%{python3_sitearch}/{mayavi,tvtk}/examples -name \*.py \
    -exec sed -i -e '/^#!\//, 1d' '{}' \;
%if 0%{?suse_version} > 1320
find %{buildroot}%{python3_sitearch}/mayavi/html/_downloads -name \*.py \
    -exec sed -i -e '/^#!\//, 1d' '{}' \;
%endif

mkdir -p %{buildroot}/%{_mandir}/man1/
mv docs/mayavi2.man %{buildroot}/%{_mandir}/man1/mayavi2.1
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/
install -p -m 644 ./docs/source/mayavi/images/mayavi2-48x48.png \
   %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/mayavi2.png
install -p -m 644 ./docs/source/mayavi/images/mayavi2-48x48.png \
   %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/tvtk_doc.png

chmod a+x %{buildroot}%{python3_sitearch}/mayavi/scripts/mayavi2.py
chmod a+x %{buildroot}%{python3_sitearch}/mayavi/tests/runtests.py
chmod a+x %{buildroot}%{python3_sitearch}/tvtk/setup.py

# script-without-shebang
chmod a-x %{buildroot}%{python3_sitearch}/mayavi/scripts/mayavi2.py
chmod a-x %{buildroot}%{python3_sitearch}/mayavi/tests/csv_files/csv_2_py
chmod a-x %{buildroot}%{python3_sitearch}/mayavi/tests/runtests.py
chmod a-x %{buildroot}%{python3_sitearch}/tvtk/setup.py

%suse_update_desktop_file -i mayavi
%suse_update_desktop_file -i tvtk_doc

mkdir -p %{buildroot}%{_docdir}/mayavi/
mkdir -p %{buildroot}%{_docdir}/python3-tvtk/
cp -r docs/build/mayavi/html %{buildroot}%{_docdir}/mayavi/
cp -r docs/build/tvtk/html %{buildroot}%{_docdir}/python3-tvtk/

# Use Unix Line endings
sed -i "s|\r||g" %{buildroot}%{_docdir}/python3-tvtk/html/objects.inv

# REMOVE UNNEEDED HIDDEN FILE
rm -r %{buildroot}%{python3_sitearch}/{tvtk,mayavi}/html/.buildinfo
rm -r %{buildroot}%{_docdir}/{python3-tvtk,mayavi}/html/.buildinfo

# recompile cache files: we have modified some sources after install
%{?python_compileall}

%fdupes %{buildroot}%{_docdir}/mayavi/
%fdupes %{buildroot}%{_docdir}/python3-tvtk/
%fdupes %{buildroot}%{python3_sitearch}/mayavi/
%fdupes %{buildroot}%{python3_sitearch}/mayavi-%{version}-py*.egg-info
%fdupes %{buildroot}%{python3_sitearch}/tvtk/
%fdupes %{buildroot}%{_datadir}/icons/

%files
%doc README*.*
%license LICENSE*.txt image_LICENSE*.txt
%{_bindir}/mayavi2
%{_mandir}/man1/mayavi2.1%{?ext_man}
%{_datadir}/applications/mayavi.desktop
%{python3_sitearch}/mayavi/
%{python3_sitearch}/mayavi-%{version}*-info
%exclude %{_docdir}/mayavi/html/

%files -n python3-tvtk
%doc README*.*
%license LICENSE*.txt image_LICENSE*.txt
%{_bindir}/tvtk_doc
%{_datadir}/applications/tvtk_doc.desktop
%{_datadir}/icons/hicolor/
%{python3_sitearch}/tvtk/
%exclude %{_docdir}/python3-tvtk/html/

%files doc
%license LICENSE*.txt image_LICENSE*.txt
%{_docdir}/mayavi/html/

%files -n python3-tvtk-doc
%license LICENSE*.txt image_LICENSE*.txt
%{_docdir}/python3-tvtk/html/

%files jupyter
%license LICENSE*.txt image_LICENSE*.txt

%changelog
* Fri Nov 26 2021 Ben Greiner <code@bnavigator.de>
- Update to 4.7.4:
  This is primarily a bugfix release that resolves issues with
  VTK-9.0.3 and VTK-9.1.x compatibility. CI now uses GitHub Actions
  and a few other minor bugs have been fixed. `mlab` imports may be
  a little faster thanks to some cleanup.
- Release note for 4.7.3:
  This is a small bug fix release mainly concerned with
  compatability with Traits 6.2.0 and soon to be release TraitsUI
  7.2.0.
- Streamline python cache compilation and deduplication
* Thu Nov 11 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python3-nose.
* Wed Sep 23 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.7.2:
  The significant update for this release is that it is compatible with the
  latest VTK-9.x series and is known to work with VTK 9.0.1 from PyPI. The
  picker UI has changed to no longer pop up a UI window but instead show the
  picked attributes on the render window directly. The original picker UI is now
  available on the scene's UI in a separate "Picker" tab. This is accessible
  from either the pipeline view when one edits the properties of a scene or
  through the "configure scene" gear icon on the scene window toolbar.
  a few dozen bugfixes, see included changes
- drop no_vtk_require.patch (obsolete)
* Wed Oct 30 2019 Todd R <toddrme2178@gmail.com>
- Fix tvtk doc .desktop file name.
- Make mayavi man file name match executable file name.
- Clean up some spec file formatting.
* Fri Sep 13 2019 Todd R <toddrme2178@gmail.com>
- Update to Mayavi 4.7.1
  + Fixes
  * Fix old pipeline errors in image actor.
  * Use the decorator for classmethod
    Instead of explicitly calling it in the class definition
  * Misc bug fixes
    Fixes 3 issues that affect the new release due to changes in traits, pyface etc.
    > Fix issue with CTF editor not showing.
    > Fix issue with lut editor not launching.
    > Fix issue with cut/pasting tree nodes and drag drop onto shell.
- Update to Mayavi 4.7.0
  + Enhancements
  * New Jupyter notebook 'ipy' backend which is now the default and
    requires that VTK's offscreen support work correctly. This backend
    requires ipywidgets and ipyevents. It allows complete interactivity and
    behaves almost exactly like a normal UI backend but inside a notebook.
    Note that this will still require an xserver or windowing toolkit unless
    VTK is compiled to be able to work without those.
  * Improve offscreen window creation.
    Creating a renderwindow in some configurations can actually make UI
    calls.  So if EGL is available we try that.  Also, when we are using
    offscreen rendering we only need a GenericRenderWindowInteractor.
    Also add a convenient set method so one can set a different interactor if needed.
  * ENH: Feature to disable automatic updates.
    This can be very handy at times when the automatic updates can trigger
    several changes that are not desirable.  For example on certain VTK
    calls, internal ModifiedEvents may be fired which will automatically
    call the update_traits method which can be wired to other events
    triggering problems.  In these cases one can use the
    `global_disable_update` function to temporarily disable updates.
  + Fixes
  * Test against ETS packages from source using travis cron jobs.
  * Use xenial linux instead of trusty
  * add fix for str conversion from bad bytes array
  * Fix issue that arises in a few of the mlab sources where when we reset to a
    polydata with a smaller number of points.
  * FIX: Fix nose leftovers in tests.
  * FIX: Escape chars in code.
  * Also catch exceptions in generating documentation
  * Some UI fixes for ivtk.
    This fixes `#734 <https://github.com/enthought/mayavi/issues/734>`_.
  * FIX: Fix set_range causing lookup table errors.
  * FIX: Fix type check
  * FIX: Fix for VTKNoneArray
  * If OSMesa is available and user requests an offscreen window, use an
    OSOpenGLRenderWindow, this will not require X and can be safely used on
    a remote server.
  * Fix bug related to SurfaceSource.scalars This bug manifests when the
    SurfaceSource object in question does not have a scalars attribute and
    many of them do not have this.
  * Fix pip installs failing.
  * Fix detection of color transfer function.
    The original code was written for very old VTK versions but ever since
    5.x we have a get_node_value method that actually provides the values of
    the nodes given an index.  We now use this instead of the earlier hack.
- Remove upstream-included catch_gen_docs_errors.patch
* Tue Apr 23 2019 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file
- Fix removal of wrong shebang lines.
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Remove useless ldconfig calls. There are no ELF libraries in the
  standard directories.
- Trim bias and filler wording from descriptions.
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to Mayavi 4.6.0
  + Features
  - Use new pyface toolkit
  - Qt5 support. This is critical for Python 3.x as this is the only toolkit
    that works with Python 3.x.
  + Fixes
  - Update installation documentation.
  - Fix warning message when updating mlab_source data without scalars/vectors.
  - Fix nbextension and missing bug with global.
  - Improve tests so Python 2.7, 3.x are tested and the tests run using VTK 8.x and 7.x.
  - Misc fixes for PyQt4 and Python 3.6.
  - Fix bug with mlab.screenshot and VTK 8.1.0.
  - Fix travis builds
  - Fix `#605 <https://github.com/enthought/mayavi/issues/605>`_: Interactors now work correctly with Qt5.
  - Fix some wxPython issues so mayavi works with recent wxPython releases.
  - Fix 8.1 issues phase 2
  - Fix 8.1 issues
  - MRG: Avoid NumPy deprecation
  - Fix bug with "p" keypress
  - VTK 8.x compatibility fixes
  - FIX: Remove debug print
  - BUG: Undo a couple of accidental trait_set changes.
  - DOC improve the mlab introduction
  - Bug fix: solve the unicode encode error in windows
  - Prevent get_tvtk_class_names from hijacking stderr
  - Prevent get_tvtk_class_names from hijacking stdout
  - FIX: Tiny spelling fix
  - FIX: Fix deprecated .set / .get use
  - Fix numpy issues in lut_manager
  - Fix long standing test failure with ply reader.
  - Fix numpy warnings.
  - Try fix appveyor test failures.
  - Add test for the fix provided in `#514 <https://github.com/enthought/mayavi/issues/514>`_.
  - Fix bug with reset method of mlab sources.
  - Fix tests
  - Update readme and add link to mailing lists.
  - Update installation instructions for conda/conda-forge/edm.
  - doc: Typo fix
  - Fix a bug with array source and vectors.
  - FIX shared data in testing backend
  - Update extract_grid.py
  - Fix pick_world bug with VTK >= 6
  - Fix bug in mouse_pick_dispatcher
  - Remove focus-stealing code
  - avoid loading nbextension via absolute URL
  - Remove known bug about Python 3 support
  - Adding information/tip about figure width
  - Fix for setuptools 28.0
  - [MRG] Added a volume_slice helper function in mlab.
  - Update readme.
  - Fix lurking old pipeline code
- Add no_vtk_require.patch
  VTK detection in setuptools fails due to a lack of .egg-info
* Thu May 24 2018 toddrme2178@gmail.com
- Use license tag
- Fix building
* Wed May 23 2018 toddrme2178@gmail.com
- Run unit tests
* Fri Aug 25 2017 toddrme2178@gmail.com
- Switch to python3
- Update to Mayavi 4.5.0
  + Enhancements
  * Jupyter notebook support!  Adds support for displaying Mayavi images or
    x3d scenes on the notebook. The x3d scenes allow one to fully interact
    with the scene in the notebook.  More documentation is available at
    :ref:`jupyter_notebook`.
  * Adds support for recording movies and animating timesteps.  See
    :ref:`animating_a_timeseries` and :ref:`animating_a_visualization` for
    more details.
  * Updated LUTs to include new matplotlib colorschemes, this includes the
    new viridis colormap.
  + Fixes
  * Fix several bugs, `#397 <https://github.com/enthought/mayavi/issues/397>`_
    where PDF files were not saved properly. Fix issues with ``tvtk.visual``
    and add many tests for it, this fixes `#387
    <https://github.com/enthought/mayavi/issues/387>`_.  Refactor the save
    screenshot dialog popups.  Fix problem with the picker point not showing
    when "p" is pressed on the scene.
  * Python 3 fixes for the jupyter notebook support.
  * Fixes `#388 <https://github.com/enthought/mayavi/issues/388>`_ where
    tubes were not showing on protein demo.
  * Add additional save options.
  * Fixes `#403 <https://github.com/enthought/mayavi/issues/403>`_ where the
    image plane widget and volume modules were broken.
  * Debug info on code gen for wrapper generation.
  * BUG: Fix slice unstructured grid module.
  * Fix typo in readme.
  * update codecov configuration
  * Documentation for QString API failure.
  * Fixes incorrect signature of ``EnvisageEngine.new_scene``.
  * Fix for unexpected test code.
  * Fix "_p_void" values in TVTK with VTK 6.x
  * Fix failing test for custom import in some circumstances
  * Removes ``array_ext.so/pyd`` on clean
  * Check if test successful with the appropriate filename.
  * Unicode trait handling for those vtk methods returning unicode data
  * ENH: Nice load pylab_luts.pkl
  * Document object identity behavior matching VTK
  * Revert "Fix savefig size and black image"
  * Added setup.py documentation for Qt requirements
  * Add VTK 6.3 and VTK 7 to travis ci
  * Fix traitsdoc setup and compliance with py3
  * Import and integer division in python3
  * Fix texture on ``mlab.surf``, issue `#211 <https://github.com/enthought/mayavi/issues/211>`_.
  * Fixes Quiver3d Failure with different argument types
  * Fix Text3D in VTK 6.0+
  * Fix savefig size and black image
  * Fix for exception when modifying extents
  * Suppresses test for VTK 6.2 (solves appVeyor random failure)
  * Forces pipeline update when LUT changes
  * Fix for test failure on mayavi -t
  * Enforce ordering of attribute labels in VTKDataSource.
  * Apply has_attribute to the output in VTKFileReader
  * Replacing links to code. and svn.enthought.com
  * Fix Camera off-centered when loading saved visualization
  * Update to use new VTK pipeline where possible.  This fixes a number of
    issues with the pipeline was not updating properly.
  * Fix issue with ``mlab.move``
  * Fix issue `#302 <https://github.com/enthought/mayavi/issues/302>`_,
    segfault when savefig is called multiple times.
  * Fix get_engine behavior when backend is changed again.
* Mon Apr 25 2016 badshah400@gmail.com
- Rename python-mayavi to mayavi.
- Avoid some rpmlint warnings by removing shebangs from
  non-executable doc files.
- Avoid rpmlint warnings by removing python byte-codes where they
  are not accompanied by the source code.
- Drop an unneeded hidden file to avoid rpmlint warning.
* Wed Mar 16 2016 stecue@gmail.com
- updated to 4.4.4
  * fixed compilation problem with vtk 7.0.0
* Mon Sep  7 2015 toddrme2178@gmail.com
- Update to 4.4.3
  * Enhancements
  - Update the readme fixing dead links
  - Use new Travis CI containers for faster builds
  - Add CI tests on Windows using Appveyor
  * Fixes
  - Remove reference cycles from various objects to fix memory leaks. Add
    unit test that provides an API to test garbage collection.
  - Fix the LUT manager to select the correct lut mode for QT backend
  - Use the python-wxtool package to speed up Travis CI build
  - Fix TVTK wrapper to allow look up with long keys for Points
  - Fix glyph to handle the masking of input points
  - Update the docs with known bugs, issues list and describe the PR
    workflow on github for development and documentation.
  - Fix TVTK wrapper to update number of cells when a cell is inserted in a
    VTK cell array
  - Fix VKTFileReader to update output when using standalone
  - Fix the sdist command
- Update to 4.4.2
  * Enhancements
  - Upgrade the VTK parser to add support for VTK 6.2.
- Update to 4.4.1
  * Fixes
  - Fix trackpad scrolling to zoom in/out smoothly on OS X.
- Update to 4.4.0
  * Enhancements
  - Add function to set data at input port, add stanford (bunny,
    dragon, lucy) examples, and use new volume mapper for new pipeline.
  - Upgrade to VTK 6.0 with VTK's new pipeline.
  * Fixes
  - Support dynamic dimensions in array source.
  - Fix MRI brain data URL.
  - More fixes for connection topology, information request and tube filter
    after upgrading to new pipeline.
  - Handle the non-Latin-1 keypresses.
  - Prevent ndarray comparisions with None.
  - Fix the trait error raised when the threshold range is updated.
  - Update installation documentation links.
  - Fix integration tests after upgrade to VTK's new pipeline.
* Mon Oct 13 2014 toddrme2178@gmail.com
- Updated source to pypi url.
* Thu Feb  6 2014 toddrme2178@gmail.com
- Update to 4.3.1
  - Bugfixes
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.3.0
  - NEW: Adding a Qt version of the gradient editor. With this, all of
    Mayavi's UI should be usable on Qt.
  - Fixed bug with incorrectly tiled snapshots while using savefig.
  - BUG: Qt: fix crashing full-screen-mode.  Fixed segfault when you click on
    full-screen and press escape/q/e.
- Update to 4.2.1
  - ENH: Add null engine to mlab.pipeline.open.
* Sun Dec  9 2012 jw@suse.com
- Requires: python-distribute for pkg_resources.
* Mon Nov 19 2012 jmatejek@suse.com
- change Requires: python-traitsGUI to python-traitsui
  (bnc#781367)
* Fri May 25 2012 toddrme2178@gmail.com
- Fix BuildRequires, Requires, and Recommends naming
* Tue May 22 2012 badshah400@gmail.com
- Update to version 4.2.0: No detailed changelog available.
- The example and integrationtests files are not installed by the
  build system any more. They are manually copied into the
  directories %%python_sitearch/mayavi/ and %%python_sitearch/tvtk/
  as applicable.
* Wed Jan 11 2012 toddrme2178@gmail.com
- Cleaned up spec file
- Renamed package from python-Mayavi to python-mayavi to match module name
- Split tvtk package
* Tue Nov  1 2011 ocefpaf@gmail.com
- Fixed build for vtk 5.8
* Sat Jun 25 2011 ocefpaf@yahoo.com.br
- updated to release 1562 ; version 4.0.0
* Wed Jun 15 2011 ocefpaf@yahoo.com.br
- updated to release 1552 ; version 3.5.0
* Sun May  1 2011 ocefpaf@yahoo.com.br
- updated to release 1521
* Sat Apr 23 2011 ocefpaf@yahoo.com.br
- updated to release 1519
* Sat Apr  9 2011 ocefpaf@yahoo.com.br
- updated to release 1514
* Sun Apr  3 2011 ocefpaf@yahoo.com.br
- updated to release 1513
* Sat Mar 12 2011 ocefpaf@yahoo.com.br
- updated revision 1506
* Sat Feb 19 2011 ocefpaf@yahoo.com.br
- updated revision 1505
* Sat Feb  5 2011 ocefpaf@yahoo.com.br
- updated revision 1497
* Sun Jan 30 2011 ocefpaf@yahoo.com.br
- updated to svn revision 26451
* Wed Dec 29 2010 ocefpaf@yahoo.com.br
- updated to svn revision 26178
* Sat Dec 18 2010 ocefpaf@yahoo.com.br
- updated to svn release 26099
* Sat Nov 20 2010 ocefpaf@yahoo.com.br
- updated to svn release 26037
* Sat Nov 13 2010 ocefpaf@yahoo.com.br
- updated to svn 25993
* Sun Oct 31 2010 ocefpaf@yahoo.com.br
- updated to svn 25932
* Sun Oct 24 2010 ocefpaf@yahoo.com.br
- updated to svn 25905
* Tue Oct 19 2010 highwaystar.ru@gmail.com
- updated to version 3.4.0
* Wed Jun 30 2010 highwaystar.ru@gmail.com
- updated to version 3.3.2
* Thu Apr 22 2010 highwaystar.ru@gmail.com
- initial release for openSUSE
- spec imported from Fedora
